@@ -2,7 +2,7 @@ from django.conf.urls import url
 from bluedot_rest_framework import import_string
 
 
-ChatConsumer = import_string('EVENT.chat.consumers')
+ChatConsumer = import_string('event.chat.consumers')
 
 
 websocket_urlpatterns = [
