@@ -9,7 +9,7 @@ from bluedot_rest_framework import import_string
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet
 from bluedot_rest_framework.utils.crypto import AESEncrypt
-from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler,jwt_get_userid_handler
 from bluedot_rest_framework.event.frontend_views import FrontendView
 
 
@@ -51,11 +51,28 @@ class EventDataDownloadView(CustomModelViewSet, FrontendView):
     def send_email(self, request, *args, **kwargs):
         data_list = request.data["data"]
         wechat_id = jwt_get_wechatid_handler(request.auth)
-        email = EventRegister.objects.get(wechat_id=wechat_id).email
+        if wechat_id == 0:
+            userid = jwt_get_userid_handler(request.auth)
+            email = EventRegister.objects.get(userid=userid).email
+        else:
+            email = EventRegister.objects.get(wechat_id=wechat_id).email
         email = AESEncrypt.decrypt(email)
         email = EmailMessage(subject='【下载资料】' + 'title',
                              from_email=settings.EMAIL_HOST_USER, to=[email])
-        url_list = [data['url'] for data in data_list]
-        # pdf = [requests.get(url).content for url in url_list]
+        email = AESEncrypt.decrypt(email)
+        for i in data_list:
+            html_content += f'<tr><td width="33"></td><td colspan="2" height="50" valign="bottom" style="color:#34454f; font-size:16px;font-weight: bold;"><a href="{i["url"]}" style="text-decoration:underline">{i["title"]}</a></td><td width="33"></td>'
+        html_content += '</tbody></table>'
 
-        return Response({"code": "200"})
+        from_email = formataddr(
+            pair=(settings.EMAIL_FROM_NAME, settings.EMAIL_HOST_USER))
+        send_mail(subject='【下载资料】',
+                  message='',
+                  html_message=html_content,
+                  from_email=from_email,
+                  recipient_list=[email])
+        return Response()
+
+
+
+  
\ No newline at end of file
