@@ -1,9 +1,10 @@
 from rest_framework import status
 from rest_framework.response import Response
 from bluedot_rest_framework import import_string
+from django.db.models import Q
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create
-from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler,jwt_get_userid_handler
 
 
 EventQuestion = import_string('event.question.models')
@@ -46,14 +47,19 @@ class EventQuestionUserView(CustomModelViewSet):
     model_class = EventQuestionUser
     serializer_class = EventQuestionUserSerializer
     filterset_fields = {
-        'event_id': ['exact'],
-    }
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        }
+        }
+
 
     def list(self, request, *args, **kwargs):
         event_id = request.query_params.get('event_id', None)
         wechat_id = jwt_get_wechatid_handler(request.auth)
-        data = EventQuestionUser.objects.filter(
-            event_id=event_id, wechat_id=wechat_id).first()
+        if wechat_id == 0:
+            userid=jwt_get_userid_handler(request.auth)
+        data = EventQuestionUser.objects.filter(Q(event_id=event_id, wechat_id=wechat_id)|Q(event_id=event_id, userid=userid)).first()
         if data:
             serializer = self.get_serializer(data)
             return Response({'code': '1', 'data': serializer.data})
