@@ -38,14 +38,14 @@ def jwt_create_token_wechat(wechat_id, unionid=''):
     """
     创建token
     """
-    userid = ''
+    userid = 0
     jwt_encode_handler = api_settings.JWT_ENCODE_HANDLER
     payload = jwt_payload_handler_wehat(userid, wechat_id, unionid)
     token = jwt_encode_handler(payload)
     return token
 
 
-def jwt_create_token_pc(userid, wechat_id='', unionid=''):
+def jwt_create_token_pc(userid, wechat_id=0, unionid=''):
     """
     创建token
     """
@@ -75,6 +75,7 @@ def jwt_decode_handler_wechat(token):
     )
 
 
+
 def jwt_get_unionid_handler(token):
     return jwt_decode_handler_wechat(token)['unionid']
 
@@ -88,7 +89,7 @@ def jwt_get_userid_handler(token):
 
 
 def jwt_get_userinfo_handler(token):
-    return jwt_get_wechatid_handler(token), jwt_get_unionid_handler(token)
+    return jwt_get_wechatid_handler(token), jwt_get_unionid_handler(token),jwt_get_userid_handler(token)
 
 
 def jwt_get_openid_handler(token, appid):
